function value = is_browser(par)

% is_browser - check browser handles
% ----------------------------------
%
% value = is_browser(par)
%
% Input:
% ------
%  par - proposed browser handles
%
% Output:
% -------
%  value - browser indicator

%--------------------------------
% Author: Harold Figueroa
%--------------------------------
% $Revision: 1600 $
% $Date: 2005-08-18 17:41:06 -0400 (Thu, 18 Aug 2005) $
%--------------------------------

% TODO: make this leaner for the simple most common case, like 'is_palette'

%--------------------------------
% HANDLE INPUT
%--------------------------------

%--
% check for figure handles
%--

if ~is_handles(par, 'figure')
	error('Input must be figure handles.');
end

%--
% handle multiple handles recursively
%--

if numel(par) > 1
	
	for k = 1:numel(par);
		value(k) = is_browser(par(k));
	end
	
	value = reshape(value, size(par)); return;
	
end

%--------------------------------
% TEST HANDLE
%--------------------------------

%--
% get browser info and check type
%--

info = get_browser_info(par);

value = ~isempty(strfind(upper(info.type), 'BROWSER'));
